@@ -16,6 +16,7 @@ from numpy import (
     degrees,
     empty,
     histogram,
+    int_,
     median,
     nan,
     ones,
@@ -173,6 +174,8 @@ class TrackEddiesObservations(GroupEddiesObservations):
         - contour_lon_e (how to do if in raw)
         - contour_lon_s (how to do if in raw)
         """
+        if self.lon.size == 0:
+            return
         lon0 = (self.lon[self.index_from_track] - 180).repeat(self.nb_obs_by_track)
         logger.debug("Normalize longitude")
         self.lon[:] = (self.lon - lon0) % 360 + lon0
@@ -228,12 +231,13 @@ class TrackEddiesObservations(GroupEddiesObservations):
         )
         h_nc.date_created = datetime.now().strftime("%Y-%m-%dT%H:%M:%SZ")
         t = h_nc.variables[VAR_DESCR_inv["j1"]]
-        delta = t.max - t.min + 1
-        h_nc.time_coverage_duration = "P%dD" % delta
-        d_start = datetime(1950, 1, 1) + timedelta(int(t.min))
-        d_end = datetime(1950, 1, 1) + timedelta(int(t.max))
-        h_nc.time_coverage_start = d_start.strftime("%Y-%m-%dT00:00:00Z")
-        h_nc.time_coverage_end = d_end.strftime("%Y-%m-%dT00:00:00Z")
+        if t.size:
+            delta = t.max - t.min + 1
+            h_nc.time_coverage_duration = "P%dD" % delta
+            d_start = datetime(1950, 1, 1) + timedelta(int(t.min))
+            d_end = datetime(1950, 1, 1) + timedelta(int(t.max))
+            h_nc.time_coverage_start = d_start.strftime("%Y-%m-%dT00:00:00Z")
+            h_nc.time_coverage_end = d_end.strftime("%Y-%m-%dT00:00:00Z")
 
     def extract_with_period(self, period, **kwargs):
         """
@@ -441,6 +445,7 @@ class TrackEddiesObservations(GroupEddiesObservations):
         if inplace:
             self.obs[yfield] = result
             return self
+        return result
 
     def median_filter(self, half_window, xfield, yfield, inplace=True):
         result = track_median_filter(
@@ -497,7 +502,7 @@ class TrackEddiesObservations(GroupEddiesObservations):
         new = self.__class__.new_like(self, nb_obs)
         new.sign_type = self.sign_type
         if nb_obs == 0:
-            logger.warning("Empty dataset will be created")
+            logger.info("Empty dataset will be created")
         else:
             for field in self.obs.dtype.descr:
                 logger.debug("Copy of field %s ...", field)
@@ -563,8 +568,11 @@ class TrackEddiesObservations(GroupEddiesObservations):
             It could be a costly operation for huge dataset
         """
         p0, p1 = self.period
+        p0_other, p1_other = other.period
+        if p1_other < p0 or p1 < p0_other:
+            return other.__class__.new_like(other, 0)
         indexs = list()
-        for i_self, i_other, t0, t1 in self.align_on(other, bins=range(p0, p1 + 2)):
+        for i_self, i_other, t0, t1 in self.align_on(other, bins=arange(p0, p1 + 2)):
             i, j, s = self.match(other, i_self=i_self, i_other=i_other, **kwargs)
             indexs.append(other.re_reference_index(j, i_other))
         indexs = concatenate(indexs)
@@ -598,6 +606,12 @@ class TrackEddiesObservations(GroupEddiesObservations):
 
     def split_network(self, intern=True, **kwargs):
         """Return each group (network) divided in segments"""
+        # Find timestep of dataset
+        # FIXME : how to know exact time sampling
+        t = unique(self.time)
+        dts = t[1:] - t[:-1]
+        timestep = median(dts)
+
         track_s, track_e, track_ref = build_index(self.tracks)
         ids = empty(
             len(self),
@@ -611,7 +625,7 @@ class TrackEddiesObservations(GroupEddiesObservations):
                 ("next_obs", "i4"),
             ],
         )
-        ids["group"], ids["time"] = self.tracks, self.time
+        ids["group"], ids["time"] = self.tracks, int_(self.time / timestep)
         # Initialisation
         # To store the id of the segments, the backward and forward cost associations
         ids["track"], ids["previous_cost"], ids["next_cost"] = 0, 0, 0
@@ -638,19 +652,19 @@ class TrackEddiesObservations(GroupEddiesObservations):
             local_ids["next_obs"][m] += i_s
         if display_iteration:
             print()
+        ids["time"] *= timestep
         return ids
 
     def set_tracks(self, x, y, ids, window, **kwargs):
         """
-        Will split one group (network) in segments
+        Split one group (network) in segments
 
         :param array x: coordinates of group
         :param array y: coordinates of group
         :param ndarray ids: several fields like time, group, ...
-        :param int windows: number of days where observations could missed
+        :param int window: number of days where observations could missed
         """
-
-        time_index = build_index(ids["time"])
+        time_index = build_index((ids["time"]).astype("i4"))
         nb = x.shape[0]
         used = zeros(nb, dtype="bool")
         track_id = 1
@@ -692,11 +706,19 @@ class TrackEddiesObservations(GroupEddiesObservations):
 
     @staticmethod
     def get_previous_obs(
-        i_current, ids, x, y, time_s, time_e, time_ref, window, **kwargs
+        i_current,
+        ids,
+        x,
+        y,
+        time_s,
+        time_e,
+        time_ref,
+        window,
+        min_overlap=0.2,
+        minimal_area=False,
     ):
         """Backward association of observations to the segments"""
-
-        time_cur = ids["time"][i_current]
+        time_cur = int_(ids["time"][i_current])
         t0, t1 = time_cur - 1 - time_ref, max(time_cur - window - time_ref, 0)
         for t_step in range(t0, t1 - 1, -1):
             i0, i1 = time_s[t_step], time_e[t_step]
@@ -709,9 +731,11 @@ class TrackEddiesObservations(GroupEddiesObservations):
             if len(ii) == 0:
                 continue
             c = zeros(len(xj))
-            c[ij] = vertice_overlap(xi[ii], yi[ii], xj[ij], yj[ij], **kwargs)
+            c[ij] = vertice_overlap(
+                xi[ii], yi[ii], xj[ij], yj[ij], minimal_area=minimal_area
+            )
             # We remove low overlap
-            c[c < 0.01] = 0
+            c[c < min_overlap] = 0
             # We get index of maximal overlap
             i = c.argmax()
             c_i = c[i]
@@ -723,10 +747,21 @@ class TrackEddiesObservations(GroupEddiesObservations):
             break
 
     @staticmethod
-    def get_next_obs(i_current, ids, x, y, time_s, time_e, time_ref, window, **kwargs):
+    def get_next_obs(
+        i_current,
+        ids,
+        x,
+        y,
+        time_s,
+        time_e,
+        time_ref,
+        window,
+        min_overlap=0.2,
+        minimal_area=False,
+    ):
         """Forward association of observations to the segments"""
         time_max = time_e.shape[0] - 1
-        time_cur = ids["time"][i_current]
+        time_cur = int_(ids["time"][i_current])
         t0, t1 = time_cur + 1 - time_ref, min(time_cur + window - time_ref, time_max)
         if t0 > time_max:
             return -1
@@ -741,9 +776,11 @@ class TrackEddiesObservations(GroupEddiesObservations):
             if len(ii) == 0:
                 continue
             c = zeros(len(xj))
-            c[ij] = vertice_overlap(xi[ii], yi[ii], xj[ij], yj[ij], **kwargs)
+            c[ij] = vertice_overlap(
+                xi[ii], yi[ii], xj[ij], yj[ij], minimal_area=minimal_area
+            )
             # We remove low overlap
-            c[c < 0.01] = 0
+            c[c < min_overlap] = 0
             # We get index of maximal overlap
             i = c.argmax()
             c_i = c[i]
