@@ -161,10 +161,10 @@ class Correspondances(list):
 
         """
         date_start = datetime(1950, 1, 1) + timedelta(
-            int(self.class_method.load_file(self.datasets[0]).time[0])
+            self.class_method.load_file(self.datasets[0]).time[0]
         )
         date_stop = datetime(1950, 1, 1) + timedelta(
-            int(self.class_method.load_file(self.datasets[-1]).time[0])
+            self.class_method.load_file(self.datasets[-1]).time[0]
         )
         return date_start, date_stop
 
@@ -350,6 +350,9 @@ class Correspondances(list):
                     self.virtual_obs = VirtualEddiesObservations.from_netcdf(
                         general_handler.groups["LastVirtualObs"]
                     )
+                    self.previous_virtual_obs = VirtualEddiesObservations.from_netcdf(
+                        general_handler.groups["LastPreviousVirtualObs"]
+                    )
                     # Load and last previous virtual obs to be merge with current => will be previous2_obs
                     # TODO : Need to rethink this line ??
                     self.current_obs = self.current_obs.merge(
@@ -584,7 +587,10 @@ class Correspondances(list):
     def longer_than(self, size_min):
         """Remove from correspondance table all association for shorter eddies than size_min"""
         # Identify eddies longer than
-        i_keep_track = where(self.nb_obs_by_tracks >= size_min)[0]
+        mask = self.nb_obs_by_tracks >= size_min
+        if not mask.any():
+            return False
+        i_keep_track = where(mask)[0]
         # Reduce array
         self.nb_obs_by_tracks = self.nb_obs_by_tracks[i_keep_track]
         self.i_current_by_tracks = (
